
require('math_snippet')
require('camera')

require('player')
require('weapon')
require('zombie')
require('tiles')
require('menu')
require('TEsound')
require('rain')
require('table_save')

--[[                                            LOVE.LOAD                                    ]]--
function love.load()

    -- Initialize the pseudo random number generator
    math.randomseed( os.time() )
    math.random(); math.random(); math.random()
    -- done. :-)

    -- initialize
    menu = init_menu()
    tiles = init_tiles()
    --load_map(tiles, "maps/map1.lua")
    player = init_player(tiles.w, tiles.h)    
    weapon = init_weapon()
    zombie = init_zombie()
    rain = init_rain()
    
    
    -- camera doesn't go behind tilemap, game is not paused
    camera:setBounds(0, 0, tiles.w - 512, tiles.h - 512)
    gameIsPaused = false
    
end

--[[                                              LOVE.KEYPRESSED                                              ]]--

-- pressing keys while on menus
function love.keypressed( key )

   if menu.gamestart then
      update_start_menu(menu, key)
   elseif menu.highscore then
      update_highscore_menu(menu, key)
   elseif menu.showHS then
      update_highscore_list(menu, key)
   elseif menu.settings then
      update_settings_menu(menu, key)
   end
   
end

-- pressing keys while on menus
function love.keyreleased( key )
    if menu.highscore then
        if key == "rshift" or key == "lshift" then
            menu.key_shift = false
	elseif key == "capslock" then
	    menu.key_capslock = false
        end
    end
end


--[[                              LOVE.QUIT   and   LOVE.FOCUS                                     ]]--

function love.quit()
  -- print("Thanks for playing! Come back soon!")
end

-- Lose focus = pause, get focus = unpause
function love.focus(f) gameIsPaused = not f end

--[[                              LOVE.MOUSEPRESSED                                     ]]--
function love.mousepressed(x, y, button)
-- CLICKING ON MENUS!!

    -- IF START MENU
    if menu.gamestart then
        --  start playing
        if menu.item == 1 and button == "l" then
            menu.showHS = false
            menu.gamestart = false
	    menu.gameover = false
	    menu.settings = false
        -- show highscores
	elseif menu.item == 2 and button == "l" then
            menu.showHS = true
            menu.gamestart = false
	    menu.gameover = false
	    menu.settings = false
        -- settings
	elseif menu.item == 3 and button == "l" then
            menu.showHS = false
            menu.gamestart = false
	    menu.gameover = false
	    menu.settings = true
        -- exit
	elseif menu.item == 4 and button == "l" then
          love.event.push('q') -- Exit
	end
    -- IF SETTINGS MENU
    elseif menu.settings then
           -- health bar
           if menu.setting == 1 and button == "l" then
                menu.health_bar = not menu.health_bar
           -- sound off / on
           elseif menu.setting == 2 and button == "l" then
                if menu.sound then
                    TEsound.disable_sound()
                    menu.sound = false
                else
                    TEsound.enable_sound()
                    TEsound.playLooping("sound/bgm.ogg", "bgm") -- stream and loop background music
                    menu.sound = true
                end
           -- screen size
           elseif menu.setting == 3 and button == "l" then
            if menu.size == 1 then
                menu.size = 2
                camera:scale(0.5,0.5)
                love.graphics.setMode(1024, 1024, false, true, 0) 
            else
                menu.size = 1
                camera:scale(2,2)
                love.graphics.setMode(512, 512, false, true, 0) 
            end
           -- back
          elseif menu.setting == 4 and button == "l" then
            menu.showHS = false
            menu.gamestart = true
	    menu.gameover = false
	    menu.settings = false
          end
    -- IF SHOW HIGHSCORES MENU
    -- if "back" selected
    elseif menu.showHS and menu.showHS_back and button == "l" then
            menu.showHS = false
            menu.gamestart = true
	    menu.gameover = false
            menu.settings = false
    end
        
        -- right click goes back to start
        if (menu.settings or menu.showHS or menu.highscore) and button == "r" then
            menu.showHS = false
            menu.gamestart = true
	    menu.gameover = false
	    menu.settings = false
        end
        
end

--[[                                              LOVE.UPDATE                                              ]]--
function love.update(dt)
      -- sound management
      TEsound.cleanup()
  
     -- if we are paused we are done
     if gameIsPaused then return end    
  
     -- camera and mouse updates
    camera:setPosition(player.x - 512/2, player.y - 512/2)
    mouse_x, mouse_y = camera:mousePosition()
    
    -- different updates for different menus
    if menu.gamestart then
        update_start_menu(menu)
        TEsound.stop("rain")
	rain.playing = false
    elseif menu.showHS then
        update_highscore_list(menu)
    elseif menu.highscore then
        blink_highscore_menu(menu, dt)
    elseif menu.settings then
        update_settings_menu(menu)
    elseif player_dead(player, zombie.list) then
        TEsound.stop("rain")
	rain.playing = false
	update_gameover_scene(menu)
	-- and don't do anything else
    else
        -- self-explanatory playing functions
        player_move(tiles, dt)
        shoot_control(player, mouse_x, mouse_y, weapon, dt)
        update_shots(weapon, dt)
        update_zombies(zombie, player, dt)
	update_rain(rain, dt)
        zombies_shot(zombie, weapon.bullets, player)
	player_attacked(player, zombie.list, dt)
	
        player_angle(player, mouse_x, mouse_y)
        player_step(player)
	player_shootstep(player, weapon)
    end
end

--[[                                               LOVE.DRAW                                   ]]--
function love.draw()

  -- use camera
  camera:set()
  
  -- self-explanatory draw functions
  draw_tiles(tiles)
  draw_player(player, menu)
  draw_rain(rain)
  draw_zombies(zombie)
  draw_shots(weapon, player)
  
  if menu.gamestart then
      draw_gamestart_menu(menu, player)
  elseif menu.gameover then
      draw_gameover_menu(menu, player)
  elseif menu.highscore then
      draw_highscore_menu(menu, player)
  elseif menu.showHS then
      draw_highscore_list(menu)
  elseif menu.settings then
      draw_settings_menu(menu)
  end
  

  -- your mouse is now a circle!
  love.graphics.setColor(200, 200, 200)
  love.mouse.setVisible(false)
  love.graphics.circle("line", mouse_x, mouse_y, 10)
 -- love.graphics.print(mouse_x..","..mouse_y, mouse_x, mouse_y)
  
  -- finish with camera
  camera:unset()
end
